parser

package
v0.92.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 11, 2025 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Parser

type Parser struct {
	// contains filtered or unexported fields
}

func New

func New(l *lexer.Lexer) *Parser

func (*Parser) ContinuationNeeded

func (p *Parser) ContinuationNeeded() bool

func (*Parser) ErrorLine added in v0.54.0

func (p *Parser) ErrorLine(forPreviousToken bool) (string, int)

ErrorLine returns the current line followed by a newline with a marker to the error position and the line number. If forPreviousToken is true, the error position is relative to the previous token instead of current one.

func (*Parser) Errors

func (p *Parser) Errors() []string

func (*Parser) ParseProgram

func (p *Parser) ParseProgram() *ast.Statements

Jump to