Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Parser ¶
type Parser struct {
// contains filtered or unexported fields
}
func (*Parser) ContinuationNeeded ¶
func (*Parser) ErrorLine ¶ added in v0.54.0
ErrorLine returns the current line followed by a newline with a marker to the error position and the line number. If forPreviousToken is true, the error position is relative to the previous token instead of current one.
func (*Parser) ParseProgram ¶
func (p *Parser) ParseProgram() *ast.Statements
Click to show internal directories.
Click to hide internal directories.